@@ -6,7 +6,7 @@ use 5.008001;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build or find autoconf
-our $VERSION = '0.06_01'; # TRIAL VERSION
+our $VERSION = '0.08_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -29,7 +29,7 @@ Alien::autoconf - Build or find autoconf
 
 =head1 VERSION
 
-version 0.06_01
+version 0.08_01
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ In your script or module:
  use Alien::autoconf;
  use Env qw( @PATH );
  
- unshift @ENV, Alien::autoconf->bin_dir;
+ unshift @PATH, Alien::autoconf->bin_dir;
 
 =head1 DESCRIPTION
 
